==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 νέο μήνυμα</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 συνδέθηκε</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Ενσύρματη Σύνδεση</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Πρωτόκολλο</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Τύπος Ασφαλείας</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Mπάντα</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kανάλι</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Πρωτεύον DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Ταχύτητα</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Συσκευή Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Δεν Συνδέθηκε</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Το καλώδιο δικτύου, αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Πιστοποίηση</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Απόκτηση Διεύθυνσης IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Συνδέθηκε</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Αποτυχία</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Απόκτηση Διεύθυνσης</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ενσύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Ενσύρματο Δίκτυο %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Ασύρματο Δίκτυο %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Συσκευή Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Το καλώδιο δικτύου, αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Δεν Συνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Αποτυχία σύνδεσης</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Απενεργοποιήστε την ενσύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ενεργοποιήστε την ενσύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Απενεργοποιήστε την ασύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ενεργοποιήστε την ασύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Απενεργοποίηση δικτύου</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ενεργοποίηση δικτύου </translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ρυθμίσεις δικτύου </translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 νέο μήνυμα</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Ενσύρματο Δίκτυο</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 συνδέθηκε</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Σύνδεση σε κρυφό δίκτυο</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Πρωτόκολλο</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Τύπος Ασφαλείας</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kανάλι</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Mπάντα</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Πρωτεύον DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Ταχύτητα</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Συσκευή Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Δεν Συνδέθηκε</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Το καλώδιο δικτύου, αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Πιστοποίηση</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Απόκτηση Διεύθυνσης IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Συνδέθηκε</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Αποτυχία</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Απόκτηση Διεύθυνσης</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ενσύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Ενσύρματο Δίκτυο %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Ασύρματο Δίκτυο %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Συσκευή Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Το καλώδιο δικτύου, αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Δεν Συνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Αποτυχία σύνδεσης</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Απενεργοποιήστε την ενσύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ενεργοποιήστε την ενσύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Απενεργοποιήστε την ασύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ενεργοποιήστε την ασύρματη σύνδεση</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Απενεργοποίηση δικτύου</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ενεργοποίηση δικτύου </translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ρυθμίσεις δικτύου </translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Ενσύρματη Σύνδεση</translation>
    </message>
</context>
</TS>
